@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/br/MathML.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
  */
 
 MathJax.Localization.addTranslation("br","MathML",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
           BadMglyph: "mglyph fall : %1",
@@ -31,7 +31,8 @@ MathJax.Localization.addTranslation("br","MathML",{
           UnexpectedTextNode: "Skoulm testenn dic'hortoz : %1",
           ErrorParsingMathML: "Fazi o tielfenna\u00F1 MathML",
           ParsingError: "Fazi o ielfenna\u00F1 MathML : %1",
-          MathMLSingleElement: "MathML a rank beza\u00F1 stummet gant un elfenn hepken"
+          MathMLSingleElement: "MathML a rank beza\u00F1 stummet gant un elfenn hepken",
+          MathMLRootElement: "Gant un elfenn \u003Cmath\u003E e rank beza\u00F1 stummet MathML, ha ket gant %1"
         }
 });
 
