@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/br/TeX.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
  */
 
 MathJax.Localization.addTranslation("br","TeX",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
           ExtraOpenMissingClose: "Briataenn digeri\u00F1 a re pe briataenn serri\u00F1 diank",
@@ -63,7 +63,34 @@ MathJax.Localization.addTranslation("br","TeX",{
           CantUseHash2: "Implij direizh eus # er patrom evit %1",
           MismatchUseDef: "An implij eus %1 ne glot ket gant an termenadur anezha\u00F1",
           RunawayArgument: "Arguzenn diechu evit %1 ?",
-          NoClosingDelim: "Ne c'haller ket kavout ur bevenner serri\u00F1 evit %1"
+          NoClosingDelim: "Ne c'haller ket kavout ur bevenner serri\u00F1 evit %1",
+          MissingScript: "Arguzenn en usskrid pe en isskrid a vank",
+          MissingOpenForSub: "Briataenn digeri\u00F1 a vank evit ar skrid en isskrid",
+          MissingOpenForSup: "Briataenn digeri\u00F1 a vank evit ar skrid en usskrid",
+          UndefinedControlSequence: "An urzh kontrolla\u00F1 %1 n'eo ket termenet",
+          DoubleExponent: "Usskrid doubl : implijit briataenno\u00F9 evit sklaeraat",
+          DoubleSubscripts: "Isskrid double : implijit briataenno\u00F9 evit sklaeraat",
+          CantUseHash1: "Ne c'hallit ket implijout an arouezenn # er mod jedoniezh",
+          MisplacedLimits: "N'eo aotreet an urzh %1 nemet gant an oberataerio\u00F9",
+          NotMathMLToken: "N'eo ket an elfenn %1 un elfenn MathML elfennel",
+          UnknownAttrForElement: "Dianav eo an doareenn %1 d'an elfenn %2",
+          ExtraAlignTab: "Arouezenn steuda\u00F1 '\u0026' dic'hortoz evit testenn an urzh /cases",
+          BracketMustBeDimension: "An argutezenn etre krochedo\u00F9 an urzh %1 a rank beza\u00F1 ur vent",
+          ExtraCloseLooking: "Briataenn serri\u00F1 dic'hortoz pa'z eo bet enklasket %1",
+          MissingCloseBracket: "Ne c'haller ket kavout ']' evit arguzenn an urzh %1",
+          MissingOrUnrecognizedDelim: "Ar bevenner a vank pe n'eo ket anavezet gant an urzh %1",
+          MissingDimOrUnits: "Ar Vent pe an unvez a vank evit an urzh %1",
+          IllegalMacroParam: "N'eo ket aotreet an arventenn dave makro",
+          IllegalAlign: "N'eo ket aotreet ar steudad evit an urzh %1",
+          ErroneousNestingEq: "Empradur direizh ar frammo\u00F9 kevatalenno\u00F9",
+          InvalidBBoxProperty: "Seblantout a ra n'eo ket an talvoud '%1' ul liv, ur ment marz bihanoc'h pe ur stil.",
+          ModelArg1: "An talvoudo\u00F9 livio\u00F9 evit ar patrom %1 o deus ezhomm eus 3 niverenn",
+          ModelArg2: "An talvoudo\u00F9 livio\u00F9 evit ar patrom %1 a rank beza\u00F1 etre %2 ha %3",
+          NewextarrowArg1: "Arguzenn genta\u00F1 an urzhiad %1 a rank beza\u00F1 anv ur seka\u00F1s kontrolla\u00F1",
+          IllegalControlSequenceName: "N'eo ket aotreet anv ar c'hontroll seka\u00F1s evit an urzh %1",
+          IllegalParamNumber: "Niver direizh a arventenno\u00F9 evit an urzh %1",
+          MissingCS: "%1 a rank beza\u00F1 heuliet gant ur seka\u00F1s kontrolla\u00F1",
+          MissingReplacementString: "Ar chadennad arouezenno\u00F9 erlec'hia\u00F1 a vank evit an termenadur %1."
         }
 });
 
