@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/en/HTML-CSS.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,14 +22,14 @@
  */
 
 MathJax.Localization.addTranslation("en","HTML-CSS",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
-          LoadWebFont: "Loading web-font %1",
-          CantLoadWebFont: "Can't load web font %1",
-          FirefoxCantLoadWebFont: "Firefox can't load web fonts from a remote host",
-          CantFindFontUsing: "Can't find a valid font using %1",
-          WebFontsNotAvailable: "Web-Fonts not available -- using image fonts instead"
+          LoadWebFont: "Loading web font %1",
+          CantLoadWebFont: "Cannot load web font %1",
+          FirefoxCantLoadWebFont: "Firefox cannot load web fonts from a remote host",
+          CantFindFontUsing: "Cannot find a valid font using %1",
+          WebFontsNotAvailable: "Web fonts not available. Using image fonts instead"
         }
 });
 
