@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/en/HelpDialog.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,19 +22,19 @@
  */
 
 MathJax.Localization.addTranslation("en","HelpDialog",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
           Help: "MathJax Help",
-          MathJax: "*MathJax* is a JavaScript library that allows page authors to include mathematics within their web pages.  As a reader, you don't need to do anything to make that happen.",
+          MathJax: "*MathJax* is a JavaScript library that allows page authors to include mathematics within their web pages. As a reader, you do not need to do anything to make that happen.",
           Browsers: "*Browsers*: MathJax works with all modern browsers including IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ and most mobile browsers.",
-          Menu: "*Math Menu*: MathJax adds a contextual menu to equations.  Right-click or CTRL-click on any mathematics to access the menu.",
-          ShowMath: "*Show Math As* allows you to view the formula's source markup for copy \u0026 paste (as MathML or in its original format).",
+          Menu: "*Math menu*: MathJax adds a contextual menu to equations. Right-click or Ctrl-click on any mathematics to access the menu.",
+          ShowMath: "*Show math as* allows you to view the formula's source markup for copy \u0026 paste (as MathML or in its original format).",
           Settings: "*Settings* gives you control over features of MathJax, such as the size of the mathematics, and the mechanism used to display equations.",
           Language: "*Language* lets you select the language used by MathJax for its menus and warning messages.",
-          Zoom: "*Math Zoom*: If you are having difficulty reading an equation, MathJax can enlarge it to help you see it better.",
+          Zoom: "*Math zoom*: If you are having difficulty reading an equation, MathJax can enlarge it to help you see it better.",
           Accessibilty: "*Accessibility*: MathJax will automatically work with screen readers to make mathematics accessible to the visually impaired.",
-          Fonts: "*Fonts*: MathJax will use certain math fonts if they are installed on your computer; otherwise, it will use web-based fonts.  Although not required, locally installed fonts will speed up typesetting.  We suggest installing the [STIX fonts](%1)."
+          Fonts: "*Fonts*: MathJax will use certain math fonts if they are installed on your computer; otherwise, it will use web-based fonts. Although not required, locally installed fonts will speed up typesetting. We suggest installing the [STIX fonts](%1)."
         }
 });
 
