@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/nl/MathMenu.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,10 +22,10 @@
  */
 
 MathJax.Localization.addTranslation("nl","MathMenu",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
-          Show: "Toon wiskunde als",
+          Show: "Wiskunde weergeven als",
           MathMLcode: "MathML code",
           OriginalMathML: "Oorspronkelijke MathML",
           TeXCommands: "TeX-commando's",
